@@ -9,9 +9,9 @@ from ladybug.epw import EPW
 from ladybug_pandas.extension_types.dtype import LadybugDType
 from ladybug_pandas.extension_types.arraytype import LadybugArrayType
 
-from ladybug_pandas import dataframe_from_collections, dataframe_from_epw
+from ladybug_pandas import dataframe_from_collections, dataframe_from_epw, series_from_collection
 
-@pytest.fixture()
+@pytest.fixture(scope='session')
 def epw():
     epw_path = 'tests/assets/epw/tokyo.epw'
 
@@ -23,11 +23,11 @@ def epw():
 
 @pytest.fixture()
 def temp_series(epw):
-    return pd.Series(LadybugArrayType._from_data_collection(epw.dry_bulb_temperature))
+    return series_from_collection(epw.dry_bulb_temperature)
 
 @pytest.fixture()
 def dnr_series(epw):
-    return pd.Series(LadybugArrayType._from_data_collection(epw.direct_normal_radiation))
+    return series_from_collection(epw.direct_normal_radiation)
 
 
 def test_addition(temp_series, dnr_series):
@@ -55,4 +55,10 @@ def test_from_epw(epw):
 
     df = dataframe_from_epw(epw)
 
-    # should not raise
\ No newline at end of file
+    # should not raise
+
+def test_si_from_si(temp_series):
+
+    equality_values = temp_series.ladybug.to_si() == temp_series
+
+    assert equality_values.all()
\ No newline at end of file
